@@ -16,10 +16,14 @@ log = logging.getLogger(__name__)
 def rmdirtree(path: AnyPath) -> None:
     """Remove the local or S3 path."""
     uri = path_to_uri(path)
+
+    if not path.exists():
+        log.info(f"Path {uri} does not exist.")
+        return
+
     log.info(f"Removing path {uri}.")
     if isinstance(path, S3Path):
-        if path.exists():
-            path.rmdir()
+        path.rmdir()
     else:
         shutil.rmtree(path, ignore_errors=True)
     assert list(path.rglob("*")) == []
